@@ -1,21 +1,41 @@
+import os
+import uuid
 from urllib.request import urlretrieve
 
 from lamin_logger import logger
-from lnschema_core import id
+from lnschema_core import id, storage
 from supabase import create_client
 
+from lndb_setup import settings
+
 from ._settings_load import load_or_create_user_settings
 from ._settings_store import Connector, settings_dir
 
 
+def get_connectore_file_url():
+    if "LAMIN_DEV" in os.environ:
+        if os.environ["LAMIN_DEV"] == "true":
+            return "https://lamin-site-assets.s3.amazonaws.com/connector_dev.env"
+    return "https://lamin-site-assets.s3.amazonaws.com/connector.env"
+
+
 def connect_hub():
-    connector_file, _ = urlretrieve(
-        "https://lamin-site-assets.s3.amazonaws.com/connector.env"
-    )
+    file_url = get_connectore_file_url()
+    connector_file, _ = urlretrieve(file_url)
     connector = Connector(_env_file=connector_file)
     return create_client(connector.url, connector.key)
 
 
+def connect_hub_with_auth():
+    hub = connect_hub()
+    user_settings = load_or_create_user_settings()
+    session = hub.auth.sign_in(
+        email=user_settings.email, password=user_settings.password
+    )
+    hub.postgrest.auth(session.access_token)
+    return hub
+
+
 def sign_up_hub(email) -> str:
     hub = connect_hub()
     password = id.id_secret()  # generate new password
@@ -75,32 +95,36 @@ def sign_in_hub(email, password, handle=None):
     return user_id, user_handle, user_name, session.access_token
 
 
-def create_instance(instance_name):
-    hub = connect_hub()
-    user_settings = load_or_create_user_settings()
-    session = hub.auth.sign_in(
-        email=user_settings.email, password=user_settings.password
-    )
-    hub.postgrest.auth(session.access_token)
-    # data = hub.table("user_instance").select("instance_id").eq("user_id", session.user.id.hex).execute()  # noqa
-    instance_id = id.id_instance()
-    data = (
-        hub.table("instance")
-        .insert({"lnid": instance_id, "handle": instance_id, "name": instance_name})
-        .execute()
-    )
-    assert len(data.data) > 0
-    data = (
-        hub.table("user_instance")
-        .insert(
-            {
-                "user_id": session.user.id.hex,
-                "instance_id": data.data[0]["id"],
-                "is_owner": True,
-            }
-        )  # noqa
-        .execute()
-    )
-    assert len(data.data) > 0
+def push_instance_if_not_exists(storage: storage):
+    hub = connect_hub_with_auth()
+
+    response = hub.table("storage").select("*").eq("id", storage.id).execute()
+    if len(response.data) == 0:
+        storage_fields = {
+            "id": storage.id,
+            "root": str(storage.root),
+            "region": storage.region,
+            "type": storage.type,
+        }
+        data = hub.table("storage").insert(storage_fields).execute()
+        assert len(data.data) == 1
+
+    # Warning: instance name is not unique
+    # we have to find another to check if an instance exists
+    response = hub.table("instance").select("*").eq("name", storage.id).execute()
+    if len(response.data) == 0:
+        instance_fields = {
+            "id": str(uuid.uuid4()),
+            "name": settings.instance.name,
+            "owner_id": hub.auth.session().user.id.hex,
+            "storage_id": storage.id,
+            "dbconfig": settings.instance._dbconfig,
+            "cache_dir": str(settings.instance.cache_dir),
+            "sqlite_file": str(settings.instance._sqlite_file),
+            "sqlite_file_local": str(settings.instance._sqlite_file_local),
+            "db": settings.instance.db,
+        }
+        data = hub.table("instance").insert(instance_fields).execute()
+        assert len(data.data) == 1
+
     hub.auth.sign_out()
-    return instance_id
